require 'rollbar/rails'

module Logging
  module Appenders
    # Factory for the Rollbar appender.
    def self.rollbar(*args)
      str = '::Logging::Appenders::Rollbar needs a name as first argument.'
      fail ArgumentError, str if args.empty?
      ::Logging::Appenders::Rollbar.new(*args)
    end

    class Rollbar < ::Logging::Appender
      def initialize(name, opts = {})
        super(name, opts)
      end

      def close(*args)
        super(false)
      end

      private

      def write(event)
        message = event.instance_of?(::Logging::LogEvent) ? layout.format(event) : event.to_s
        return if message.empty?

        exception = RuntimeError.new(message)
        severity =
          case Logging::LNAMES[event.level]
          when 'DEBUG', 'INFO'
            'info'
          when 'WARN'
            'warning'
          when 'ERROR', 'FATAL'
            'error'
          end

        ::Rollbar.error(exception, severity: severity)
        self
      end
    end
  end
end